@@ -32,6 +32,12 @@ class AlgorithmsRegistry:
     def get_algorithm_class(ml_task, algorithm_name):
         return AlgorithmsRegistry.registry[ml_task][algorithm_name]["class"]
 
+    @staticmethod
+    def get_long_name(ml_task, algorithm_name):
+        return AlgorithmsRegistry.registry[ml_task][algorithm_name][
+            "class"
+        ].algorithm_name
+
 
 # Import algorithm to be registered
 import supervised.algorithms.random_forest
@@ -39,3 +45,6 @@ import supervised.algorithms.xgboost
 import supervised.algorithms.decision_tree
 import supervised.algorithms.baseline
 import supervised.algorithms.lightgbm
+import supervised.algorithms.extra_trees
+import supervised.algorithms.catboost
+import supervised.algorithms.linear
