@@ -14,6 +14,9 @@ class TimeConstraint(Callback):
         self.name = params.get("name", "time_constraint")
         self.train_time_limit = params.get("train_seconds_time_limit", 60)  # in seconds
         self.min_steps = params.get("min_steps")
+        self.total_time_limit = params.get("total_time_limit")
+        self.total_time_start = params.get("total_time_start")
+        
         self.last_iteration_time = 0
         self.iterations_count = 0
 
@@ -34,6 +37,12 @@ class TimeConstraint(Callback):
             )
         )
 
+        if self.total_time_limit is not None:
+            # not time left, stop now
+            if time.time() - self.total_time_start > self.total_time_limit:
+                self.learner.stop_training = True
+                return
+
         if time.time() - self.train_start_time > self.train_time_limit:
             self.learner.stop_training = True
             log.info("Terminating learning, time limit reached")
