@@ -20,7 +20,9 @@ logger.setLevel(LOG_LEVEL)
 
 
 class MljarTuner:
-    def __init__(self, tuner_params, algorithms, ml_task, validation, seed):
+    def __init__(
+        self, tuner_params, algorithms, ml_task, validation, explain_level, seed
+    ):
         logger.debug("MljarTuner.__init__")
         self._start_random_models = tuner_params.get("start_random_models", 5)
         self._hill_climbing_steps = tuner_params.get("hill_climbing_steps", 3)
@@ -28,6 +30,7 @@ class MljarTuner:
         self._algorithms = algorithms
         self._ml_task = ml_task
         self._validation = validation
+        self._explain_level = explain_level
         self._seed = seed
 
         self._unique_params_keys = []
@@ -37,9 +40,9 @@ class MljarTuner:
         generated_params = []
         for model_type in self._algorithms:
             for i in range(self._start_random_models):
-                if i > 0 and model_type == "Baseline":
+                if i > 0 and model_type in ["Baseline", "Linear"]:
                     break
-                if i > 4 and model_type == "Decision Tree":
+                if i > 2 and model_type == "Decision Tree":
                     break
 
                 logger.info("Generate parameters for model #{0}".format(models_cnt + 1))
@@ -73,7 +76,7 @@ class MljarTuner:
             unique_model_types = np.unique(df_models.model_type)
 
             for m_type in unique_model_types:
-                if m_type in ["Baseline", "Decision Tree"]:
+                if m_type in ["Baseline", "Decision Tree", "Linear"]:
                     # dont tune Baseline and Decision Tree
                     continue
                 models = df_models[df_models.model_type == m_type]["model"]
@@ -135,6 +138,7 @@ class MljarTuner:
             model_params["learner"]["num_class"] = num_class
 
         model_params["ml_task"] = self._ml_task
+        model_params["explain_level"] = self._explain_level
 
         return model_params
 
